# -*- coding: utf-8 -*-
""" Module of order parameter growing

Ported from ltfat_2.1.0/comp/assert_groworder.m

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import numpy as np


def assert_groworder(order):
    """Grow the order parameter

    - Input parameter:

    :param tuple order: Order indices obtained with
        :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre`

    - Ouput parameter:

    :return: Order indices
    :rtype: tuple

    ``assert_groworder`` is meant to be used in conjunction with
    :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre` and
    :func:`~ltfatpy.comp.assert_sigreshape_post.assert_sigreshape_post`. It is
    used to modify the **order** parameter in between calls in order to expand
    the processed dimension by ``1``, i.e. for use in a routine that creates 2D
    output from 1D input, for instance in :func:`~ltfatpy.gabor.dgt.dgt` or
    :func:`filterbank`.
    """

    if len(order) > 1:
        # We only need to handle the non-trivial order, where dim>1
        p = order[0]
        # Shift orders higher that the working dimension by 1, to make room for
        # the new dimension, but leave lower dimensions untouched.
        ordernp = np.asarray(order)
        ordernp[ordernp > p] = ordernp[ordernp > p]+1
        return (p, p+1) + tuple(ordernp[1:])
    return order
