# -*- coding: utf-8 -*-
""" Module of original permuted shape restoration

Ported from ltfat_2.1.0/comp/assert_sigreshape_post.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import numpy as np


def assert_sigreshape_post(f, dim, permutedshape, order):
    """Restore the original permuted shape

    - Input parameters:

    :param numpy.ndarray f: Reshaped signal as returned in **f** by
        :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre`
    :param int dim: Verified dim as returned in **dim** by
        :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre`
    :param tuple permutedshape: **permutedshape** value as returned by
        :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre`
    :param tuple order: **order** value as returned by
        :func:`~ltfatpy.comp.assert_sigreshape_pre.assert_sigreshape_pre`

    - Output parameters:

    :returns: The signal reshaped to its original shape
    :rtype: numpy.ndarray

    .. warning::
        This function returns a view of **f** if possible. Any value changed
        in this view will also be changed in **f**.
    """

    f = f.reshape(permutedshape)

    if dim > 0:
        # Undo the permutation.
        f = f.transpose(np.argsort(order))

    return f
