# -*- coding: utf-8 -*-
""" Module of comp_sigreshape_pre calculation

Ported from ltfat_2.1.0/comp/comp_sigreshape_pre.m

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import numpy as np


def comp_sigreshape_pre(f, do_ndim):
    """Set good dimensionality

    .. warning::
        This function returns **f** or a view of **f**. Any value changed in
        the returned variable will also be changed in **f**.
    """
    if not isinstance(f, np.ndarray):
        raise ValueError("f should be a numpy array.")
    elif f.size == 0 or (not np.issubdtype(f.dtype, np.float) and
                         not np.issubdtype(f.dtype, np.complex) and
                         not np.issubdtype(f.dtype, np.integer)):
        raise ValueError('The input must be non-empty numeric.')

    wasrow = False

    # Rember the shape if f is multidimensional.
    remembershape = f.shape
    fd = len(remembershape)

    # Multi-dimensional mode, apply to first dimension.
    if fd > 2:
        if do_ndim > 0 and fd > do_ndim:
            raise ValueError('Cannot process multidimensional arrays.')

        fl = f.shape[0]
        W = np.prod(remembershape)//fl

        # Reshape to matrix if multidimensional.
        f = f.reshape((fl, W))
    else:
        if f.shape[0] == 1:
            wasrow = True
            # Make f a column vector.
            f = f.squeeze()
        fl = f.shape[0]
        if f.ndim > 1:
            W = f.shape[1]
        else:
            W = 1

    return (f, fl, W, wasrow, remembershape)
