# -*- coding: utf-8 -*-

cdef enum dgt_phasetype:
    FREQINV = 0
    TIMEINV = 1

ctypedef size_t ltfatInt

# Values extracted from fftw3.h
cdef enum dct_kind:
    DCTI = 3
    DCTIII = 4
    DCTII = 5
    DCTIV = 6

# Values extracted from fftw3.h
cdef enum dst_kind:
    DSTI = 7
    DSTIII = 8
    DSTII = 9
    DSTIV = 10


# pgauss functions declarations
cdef extern void pgauss_d(const ltfatInt L, const double w, const double c_t,
                          double * g)

cdef extern void pgauss_cmplx_d(const ltfatInt L, const double w,
                                const double c_t, const double c_f,
                                const double complex * g)

# DGT functions declarations
cdef extern void dgt_long_cd(const double complex * f,
                             const double complex * g,
                             const ltfatInt L, const ltfatInt W,
                             const ltfatInt a, const ltfatInt M,
                             const dgt_phasetype ptype, double complex * cout)

cdef extern void dgt_long_d(const double * f, const double * g,
                            const ltfatInt L, const ltfatInt W,
                            const ltfatInt a, const ltfatInt M,
                            const dgt_phasetype ptype, double complex * cout)

cdef extern void dgtreal_long_d(const double * f, const double * g,
                                const ltfatInt L, const ltfatInt W,
                                const ltfatInt a, const ltfatInt M,
                                const dgt_phasetype ptype,
                                double complex * cout)

cdef extern void dgt_fb_cd(const double complex * f, const double complex * g,
                           const ltfatInt L, const ltfatInt gl,
                           const ltfatInt W, const ltfatInt a,
                           const ltfatInt M, const dgt_phasetype ptype,
                           double complex * cout)

cdef extern void dgt_fb_d(const double * f, const double * g,
                          const ltfatInt L, const ltfatInt gl,
                          const ltfatInt W, const ltfatInt a,
                          const ltfatInt M, const dgt_phasetype ptype,
                          double complex * cout)

cdef extern void dgtreal_fb_d(const double * f, const double * g,
                              const ltfatInt L, const ltfatInt gl,
                              const ltfatInt W, const ltfatInt a,
                              const ltfatInt M, const dgt_phasetype ptype,
                              double complex * cout)

cdef extern void idgt_fb_d(const double complex * F, const double complex * g,
                           const ltfatInt L, const ltfatInt gl,
                           const ltfatInt W, const ltfatInt a,
                           const ltfatInt M, const dgt_phasetype ptype,
                           double complex * f)

cdef extern void idgtreal_fb_d(const double complex * F, const double * g,
                               const ltfatInt L, const ltfatInt gl,
                               const ltfatInt W,
                               const ltfatInt a, const ltfatInt M,
                               const dgt_phasetype ptype, double * f)

cdef extern void idgt_long_d(const double complex * F,
                             const double complex * g,
                             const ltfatInt L, const ltfatInt W,
                             const ltfatInt a, const ltfatInt M,
                             const dgt_phasetype ptype,
                             double complex * f)

cdef extern void idgtreal_long_d(const double complex * F, const double * g,
                                 const ltfatInt L, const ltfatInt W,
                                 const ltfatInt a, const ltfatInt M,
                                 const dgt_phasetype ptype, double * f)

cdef extern void gabdual_long_d(const double * g,
                                const ltfatInt L, const ltfatInt R,
                                const ltfatInt a,
                                const ltfatInt M, double * gd)

cdef extern void gabdual_long_cd(const double complex * g,
                                 const ltfatInt L, const ltfatInt R,
                                 const ltfatInt a,
                                 const ltfatInt M, double complex * gd)

cdef extern void gabtight_long_d(const double * g,
                                 const ltfatInt L, const ltfatInt R,
                                 const ltfatInt a, const ltfatInt M,
                                 double * gd)

cdef extern void gabtight_long_cd(const double complex * g,
                                  const ltfatInt L, const ltfatInt R,
                                  const ltfatInt a, const ltfatInt M,
                                  double complex * gd)

cdef extern void dct_d(const double * f, const ltfatInt L, const ltfatInt W,
                       double * cout, const dct_kind kind)

cdef extern void dct_cd(const double complex * f, const ltfatInt L,
                        const ltfatInt W, double complex * cout,
                        const dct_kind kind)

cdef extern void dst_d(const double * f, const ltfatInt L, const ltfatInt W,
                       double * cout, const dst_kind kind)

cdef extern void dst_cd(const double complex * f, const ltfatInt L,
                        const ltfatInt W, double complex * cout,
                        const dst_kind kind)

