# -*- coding: utf-8 -*-
"""Module of FFT for real valued data computation

Ported from ltfat_2.1.0/fourier/fftreal.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import numpy as np


def fftreal(f, N=None, dim=0):
    """FFT for real valued input data

    - Usage:

        | ``c = fftreal(f)``
        | ``c = fftreal(f, N, dim)``

    - Input parameters:

    :param numpy.ndarray f: Real valued input array
    :param int N: FFT length
    :param int dim: Axis over which to compute the FFT. By default the first
        axis is used.

    - Output parameters:

    :returns: Discrete Fourier coefficients of **f** for positive frequencies
    :rtype: numpy.ndarray

    ``fftreal(f)`` computes the coefficients corresponding to the positive
    frequencies of the FFT of the real valued input signal **f**.

    The function takes the same arguments as :func:`numpy.fft.rfft`. See the
    help on this function for a thorough description.

    .. note::

        This Python port doesn't use the C core of LTFAT to implement the
        FFT for real arrays as in the Octave version.

        Instead it direclty uses the implementation available in numpy.

        This can lead to sightly different results when comparing the results
        of the Octave and Python versions of fftreal.

    .. seealso:: :func:`~ltfatpy.fourier.ifftreal.ifftreal`,
        :func:`~ltfatpy.fourier.dft.dft`

    """

    # Note: There is a bug in fftreal in ltfat 2.1.0 for Octave. It has been
    # reported and confirmed here:
    # http://sourceforge.net/p/ltfat/bugs/118/
    # This Python port is not subject to this bug.

    return np.fft.rfft(f, N, dim)
