# -*- coding: utf-8 -*-
"""Module of inverse FFT for real valued data computation

Ported from ltfat_2.1.0/fourier/ifftreal.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import numpy as np


def ifftreal(c, N, dim=0):
    """Inverse FFT for real valued signals

    - Usage:

        | ``f = ifftreal(c, N)``
        | ``f = ifftreal(c, N, dim)``

    - Input parameters:

    :param numpy.ndarray c: Discrete Fourier coefficients of a real array for
        positive frequencies
    :param int N: IFFT length
    :param int dim: Axis over which to compute the IFFT. By default the first
        axis is used.

    - Output parameters:

    :returns: Reconstructed signal
    :rtype: numpy.ndarray

    ``ifftreal(c, N)`` computes an inverse FFT of the positive frequency
    Fourier coefficients **c**. The length **N** must always be specified,
    because the correct transform length cannot be determined from the
    size of **c**.

    ``ifftreal(c, N, dim)`` does the same along dimension **dim**.

    .. note::

        This Python port doesn't use the C core of LTFAT to implement the
        inverse FFT for real arrays as in the Octave version.

        Instead it direclty uses the implementation available in numpy.

        This can lead to sightly different results when comparing the results
        of the Octave and Python versions of ifftreal.

    .. seealso::  :func:`~ltfatpy.fourier.fftreal.fftreal`

    """

    return np.fft.irfft(c, N, dim)
