# -*- coding: utf-8 -*-
"""Module of dgtlength calculation

Ported from ltfat_2.1.0/gabor/dgtlength.m

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import six
import numpy as np

from ltfatpy.tools.lcm import lcm


def dgtlength(Ls, a, M):
    """DGT length from signal

    - Usage:

         | ``L = dgtlength(Ls, a, M)``

    - Input parameters:

    :param int Ls: Signal length
    :param int a: Length of time shift.
    :param int M: Number of channels.

    - Output parameters:

    :return: Corrected signal length
    :rtype: int

    ``dgtlength(Ls, a, M)`` returns the length of a Gabor system that is long
    enough to expand a signal of length **Ls**. Please see the help on
    :func:`~ltfatpy.gabor.dgt.dgt` for an explanation of the parameters **a**
    and **M**.

    .. seealso:: :func:`~ltfatpy.gabor.dgt.dgt`
    """
    if not(isinstance(M, six.integer_types)):
        raise TypeError('M must be an integer')
    if not(isinstance(a, six.integer_types)):
        raise TypeError('a must be an integer')
    if M <= 0:
        raise ValueError('M must be positive')
    if a <= 0:
        raise ValueError('a must be positive')
    if not(isinstance(Ls, (six.integer_types, float, complex))):
        raise TypeError('Ls must be a scalar')

    Lsmallest = lcm(a, M)
    L = np.ceil(Ls/Lsmallest)*Lsmallest
    return int(L)
