# -*- coding: utf-8 -*-
"""Module of dgt coefficients plotting

Ported from ltfat_2.1.0/gabor/plotdgt.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import numpy as np

from ltfatpy.gabor.tfplot import tfplot


def plotdgt(coef, a, **kwargs):
    """Plot dgt coefficients

    - Input parameters:

    :param numpy.ndarray coef: Gabor coefficients
    :param int a: Length of time shift used when computing **coef**
    :param `**kwargs`: ``plotdgt`` supports all the optional parameters of
        :func:`~ltfatpy.gabor.tfplot.tfplot`. Please see the help of
        :func:`~ltfatpy.gabor.tfplot.tfplot` for an exhaustive list.

    - Output parameters:

    :returns: The processed image data used in the plotting. Inputting this
        data directly to :func:`~matplotlib.pyplot.matshow` or similar
        functions will create the plot. This is useful for custom
        post-processing of the image data.
    :rtype: numpy.ndarray

    ``plotdgt(coef, a)`` plots the Gabor coefficients **coef**. The
    coefficients must have been produced with a time shift of **a**.

    The figure generated by this function places the zero-frequency in
    the center of the y-axis, with positive frequencies above and
    negative frequencies below.

    .. seealso:: :func:`~ltfatpy.gabor.dgt.dgt`,
        :func:`~ltfatpy.gabor.tfplot.tfplot`,
        :func:`~ltfatpy.gabor.sgram.sgram`,
        :func:`~ltfatpy.gabor.plotdgtreal.plotdgtreal`

    """

    M = coef.shape[0]

    # Move zero frequency to the center and Nyquist frequency to the top.
    if M % 2 == 0:
        coef = np.roll(coef, M//2-1, axis=0)
        yr = np.array([-1.+2./M, 1.])
    else:
        coef = np.roll(coef, (M-1)//2, axis=0)
        yr = np.array([-1.+2./M, 1.-2./M])

    coef = tfplot(coef, a, yr, **kwargs)
    return coef
