# -*- coding: utf-8 -*-
"""Module of dgtreal coefficients plotting

Ported from ltfat_2.1.0/gabor/plotdgtreal.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import numpy as np

from ltfatpy.gabor.tfplot import tfplot


def plotdgtreal(coef, a, M, **kwargs):
    """Plot dgtreal coefficients

    :param numpy.ndarray coef: Gabor coefficients
    :param int a: Length of time shift used when computing **coef**
    :param int M: Number of modulations used when computing **coef**
    :param `**kwargs`: ``plotdgtreal`` supports all the optional parameters of
        :func:`~ltfatpy.gabor.tfplot.tfplot`. Please see the help of
        :func:`~ltfatpy.gabor.tfplot.tfplot` for an exhaustive list.

    - Output parameters:

    :returns: The processed image data used in the plotting. Inputting this
        data directly to :func:`~matplotlib.pyplot.matshow` or similar
        functions will create the plot. This is useful for custom
        post-processing of the image data.
    :rtype: numpy.ndarray

    ``plotdgtreal(coef, a, M)`` plots Gabor coefficients from
    :func:`~ltfatpy.gabor.dgtreal.dgtreal`. The parameters **a** and **M**
    must match those from the call to :func:`~ltfatpy.gabor.dgtreal.dgtreal`.

    .. seealso:: :func:`~ltfatpy.gabor.dgtreal.dgtreal`,
        :func:`~ltfatpy.gabor.tfplot.tfplot`,
        :func:`~ltfatpy.gabor.sgram.sgram`,
        :func:`~ltfatpy.gabor.plotdgt.plotdgt`

    """

    if M % 2 == 0:
        yr = np.array([0., 1.])
    else:
        yr = np.array([0, 1.-2./M])

    coef = tfplot(coef, a, yr, **kwargs)

    return coef
