# -*- coding: utf-8 -*-
"""Module of glockenspiel signal loading

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

from scipy.io.wavfile import read as wavread
import pkg_resources
import numpy as np


def gspi():
    """Load the 'glockenspiel' test signal

    - Usage:

        | ``(s, fs) = gspi()``

    - Output parameters:

    :returns: ``(s, fs)``
    :rtype: tuple

    :var numpy.ndarray s: 'glockenspiel' signal
    :var int fs: sampling frequency in Hz

    ``gspi`` loads the 'glockenspiel' signal. This is a recording of a simple
    tune played on a glockenspiel. It is 262144 samples long, mono, recorded
    at 44100 Hz using 16 bit quantization.

    This signal, and other similar audio tests signals, can be found on
    the EBU SQAM test signal CD http://tech.ebu.ch/publications/sqamcd.
    """

    f = pkg_resources.resource_stream(__name__, "gspi.wav")

    fs, s = wavread(f)
    s = s.astype(np.float64) / 2.**15.
    return (s, fs)
