# -*- coding: utf-8 -*-
"""Module of linus signal loading

Ported from ltfat_2.1.0/signals/linus.m

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

from scipy.io.wavfile import read as wavread
import pkg_resources
import numpy as np


def linus():
    """Load the 'linus' test signal

    - Usage:

        | ``(s, fs) = linus()``

    - Output parameters:

    :returns: ``(s, fs)``
    :rtype: tuple

    :var numpy.ndarray s: 'linus' signal
    :var int fs: sampling frequency in Hz

    ``linus`` loads the 'linus' signal. It is a recording of Linus Thorvalds
    pronouncing the words "Hello. My name is Linus Thorvalds, and I pronounce
    Linux as Linux".

    The signal is 41461 samples long and is sampled at 8 kHz.

    See `<http://www.paul.sladen.org/pronunciation/>`_.
    """

    f = pkg_resources.resource_stream(__name__, "linus.wav")

    fs, s = wavread(f)
    s = s.astype(np.float64) / 2.**15.
    return (s, fs)
