# -*- coding: utf-8 -*-
"""Test of the assert_sigreshape_post function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import random
import numpy as np
from ltfatpy.comp.assert_sigreshape_pre import assert_sigreshape_pre as aspre
from ltfatpy.comp.assert_sigreshape_post import assert_sigreshape_post\
                                                as aspost
import functools


class TestAssertSigReshapePost(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('Start TestAssertSigReshapePost')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Basic usual cases """
        L = random.randint(5, 200)
        f = np.arange(0, L, dtype=np.float_)
        (g, L, Ls, W, dim, permutedshape, order) = aspre(f)
        fres = aspost(f, dim, permutedshape, order)
        mess = "\nL = {0:d}, Ls = {1:d}, W = {2:d}, dim = {3:d}, g.shape = "
        mess += str(g.shape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(L, Ls, W, dim)
        np.testing.assert_array_equal(f, fres, mess)

    def test_twodim(self):
        """ Many channels signals """
        shapef = tuple([random.randint(5, 20) for _ in range(2)])
        L = functools.reduce(lambda x, y: x*y, shapef)
        f = np.arange(0, L, dtype=np.complex_)
        f = f.reshape(shapef)
        (g, L, Ls, W, dim, permutedshape, order) = aspre(f)
        fres = aspost(f, dim, permutedshape, order)
        mess = "\nL = {0:d}, Ls = {1:d}, W = {2:d}, dim = {3:d}, g.shape = "
        mess += str(g.shape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(L, Ls, W, dim)
        np.testing.assert_array_equal(f, fres, mess)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(
                                  TestAssertSigReshapePost)
    unittest.TextTestRunner(verbosity=2).run(suite)
