# -*- coding: utf-8 -*-
"""Test of the compt_dct function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np


from ltfatpy.comp.comp_dct import comp_dct
from ltfatpy.tests.datasets.read_comp_dct_signal_ex_mat import DctSignals
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestCompDCT(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('comp_dct_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        dgs = DctSignals(self.filename)
        (TYPE, SIGNAL, L, W, DCT, dct_type) = dgs.read_next_signal()
        while TYPE != '':
            mess = "\n\nTYPE = " + TYPE + "\nL = " + str(L)
            mess += "\nW = " + str(W) + "\ndct_type = " + str(dct_type)
            mess += "\nSIGNAL =\n" + str(SIGNAL)
            mess += "\nDCT\n" + str(DCT)
            pydct = comp_dct(SIGNAL, dct_type)
            mess += "\npydct = \n" + str(pydct)
            self.assertTrue(np.linalg.norm(pydct-DCT) <= 1e-10, mess)
            (TYPE, SIGNAL, L, W, DCT, dct_type) = dgs.read_next_signal()

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestCompDCT)
    unittest.TextTestRunner(verbosity=2).run(suite)
