# -*- coding: utf-8 -*-
"""Test of the comp_hermite function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
from ltfatpy.comp.comp_hermite import comp_hermite
# import matplotlib.pyplot as plt


class TestCompHermite(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.x = np.arange(10)

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        y = comp_hermite(0, self.x)
        yres = np.array([7.51125544e-01, 4.55580672e-01, 1.01653788e-01,
                         8.34425107e-03, 2.51974549e-04, 2.79918439e-06,
                         1.14396268e-08, 1.71987833e-11, 9.51237824e-15,
                         1.93546809e-18])
        np.testing.assert_array_almost_equal(y, yres, 6)

        y = comp_hermite(1, self.x)
        yres = np.array([0.00000000e+00, 6.44288365e-01, 2.87520332e-01,
                         3.54016591e-02, 1.42538330e-03, 1.97932227e-05,
                         9.70684525e-08, 1.70259268e-10, 1.07620275e-13,
                         2.46344870e-17])
        np.testing.assert_array_almost_equal(y, yres, 6)

        y = comp_hermite(2, self.x)
        yres = np.array([-5.31125966e-01, 3.22144183e-01, 5.03160581e-01,
                         1.00304701e-01, 5.52336028e-03, 9.69867910e-05,
                         5.74321677e-07, 1.17965350e-09, 8.54235929e-13,
                         2.20341800e-16])
        np.testing.assert_array_almost_equal(y, yres, 6)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestCompHermite)
    unittest.TextTestRunner(verbosity=2).run(suite)
