# -*- coding: utf-8 -*-
"""Test of the comp_pgauss function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import random
import numpy as np
from numpy import linalg as LA
from ltfatpy.comp.comp_pgauss import comp_pgauss
from math import sqrt
# import matplotlib.pyplot as plt


class TestCompPgauss(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.L = random.randint(10, 100)

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        g_r1 = comp_pgauss(self.L)
        g_r2 = comp_pgauss(self.L, 1, 0, 0)
        self.assertTrue(np.array_equal(g_r1, g_r2))

    def test_properties(self):
        g = comp_pgauss(self.L)
        gf = np.fft.fft(g)/sqrt(self.L)
        self.assertTrue(LA.norm(g-gf) <= 1e-10)
        gc = comp_pgauss(self.L, c_f=2.0)
        for val in gc:
            self.assertTrue(type(val) is np.complex128)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestCompPgauss)
    unittest.TextTestRunner(verbosity=2).run(suite)
