# -*- coding: utf-8 -*-
"""Test of the comp_sigreshape_pre and comp_sigreshape_post functions

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import random
import numpy as np
from ltfatpy.comp.comp_sigreshape_pre import comp_sigreshape_pre as cpre
from ltfatpy.comp.comp_sigreshape_post import comp_sigreshape_post as cpost
import functools


class TestCompSigReshape(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('Start TestCompSigReshape')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        self.assertRaises(ValueError, cpre, "toto", 10)
        self.assertRaises(ValueError, cpre, np.empty((0,)), 10)
        self.assertRaises(ValueError, cpre, np.ones((10, 10, 2)), 1)

    def test_onedim(self):
        """ One channel """
        L = random.randint(5, 200)
        f = np.arange(0, L, dtype=np.float_)
        (fin, fl, W, wasrow, remembershape) = cpre(f, 0)
        fres = cpost(fin, fl, wasrow, remembershape)
        mess = "\nfl = {:d}, W = {:d}, wasrow = {:d},remembershape.shape = "
        mess += str(remembershape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(fl, W, wasrow)
        np.testing.assert_array_equal(f, fres, mess)
        L = random.randint(5, 200)
        f = np.arange(0, L, dtype=np.float_)
        f.resize((1, L))
        (fin, fl, W, wasrow, remembershape) = cpre(f, 0)
        fres = cpost(fin, fl, wasrow, remembershape)
        mess = "\nfl = {:d}, W = {:d}, wasrow = {:d},remembershape.shape = "
        mess += str(remembershape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(fl, W, wasrow)
        np.testing.assert_array_equal(f, fres, mess)

    def test_twodim(self):
        """ Many channels signals """
        shapef = tuple([random.randint(5, 20) for _ in range(2)])
        L = functools.reduce(lambda x, y: x*y, shapef)
        f = np.arange(0, L, dtype=np.complex_)
        f = f.reshape(shapef)
        (fin, fl, W, wasrow, remembershape) = cpre(f, 1)
        fres = cpost(fin, fl, wasrow, remembershape)
        mess = "\nfl = {:d}, W = {:d}, wasrow = {:d},remembershape.shape = "
        mess += str(remembershape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(fl, W, wasrow)
        np.testing.assert_array_equal(f, fres, mess)

    def test_multidim(self):
        """ Multidimensionnal signals """
        shapef = tuple([random.randint(5, 20) for _ in range(4)])
        L = np.prod(shapef)
        f = np.arange(0, L, dtype=np.complex_)
        f = f.reshape(shapef)
        (fin, fl, W, wasrow, remembershape) = cpre(f, 5)
        fres = cpost(fin, fl, wasrow, remembershape)
        mess = "\nfl = {:d}, W = {:.2f}, wasrow = {:d},remembershape.shape = "
        mess += str(remembershape) + ", f.shape = " + str(f.shape)
        mess += ", fres.shape = " + str(fres.shape)
        mess = mess.format(fl, W, wasrow)
        np.testing.assert_array_equal(f, fres, mess)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestCompSigReshape)
    unittest.TextTestRunner(verbosity=2).run(suite)
