# -*- coding: utf-8 -*-
"""Read .mat data files generated with the Matlab version of Ltfat and
containing signals, dct from comp_dct for validations.

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import scipy.io


class DctSignals:
    """This class opens the file and provides :func:`read_next_signal`
    method for reading each (type, signal, L, W, dct, dct_type) tuples
    contained in the file.
    """

    def __init__(self, filename):
        """Constructor

        - Input parameter:

        :param str filename: Name of the matlab data file
        """
        self.Data = scipy.io.loadmat(filename, struct_as_record=False,
                                     squeeze_me=True)['Data']
        self.ind = 0
        self.size = self.Data.shape[0]

    def read_next_signal(self):
        """Read the next signal of the file.

        - Usage:

            | :literal:`(type, signal, L, W, dct, dct_type) =
            |                        DctSignals("file.mat").read_next_signal()`

        - Output parameters:

        :returns:
            :literal:`(type, signal, L, W, dct, dct_type)`

            Empty strings if all signals have been read.
        """
        if(self.ind >= self.size):
            return ('', '', '', '', '', '')

        TYPE = str(self.Data[self.ind].rname)
        L = self.Data[self.ind].L
        W = self.Data[self.ind].W
        dct_type = self.Data[self.ind].dct_type
        SIGNAL = self.Data[self.ind].f
        DCT = self.Data[self.ind].cc
        self.ind += 1
        return (TYPE, SIGNAL, L, W, DCT, dct_type)
