# -*- coding: utf-8 -*-
"""Read .mat data files generated with the Matlab version of Ltfat and
containing windows and their gabor operator diagonals for validation.

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import scipy.io


class DiagExamples:
    """This class opens the file and provides :func:`read_next_signal`
    method for reading each (g, diag) tuples contained in the file.
    """

    def __init__(self, filename):
        """Constructor

        - Input parameter:

        :param str filename: Name of the matlab data file
        """
        self.Data = scipy.io.loadmat(filename, struct_as_record=False,
                                     squeeze_me=True)['Data']
        self.ind = 0
        self.size = self.Data.shape[0]

    def read_next_frame(self):
        """Read the next frame of the file.

        - Usage:

            | `(L, a, M, gl, G, DIAG) = DiagExamples("file.mat").
            | read_next_signal()`

        - Output parameters:

        :returns:
            :literal:`(L, a, M, gl, G, DIAG)`

            Empty strings if all frames have been read.
        """
        if(self.ind >= self.size):
            return ('', '', '', '', '', '')

        L = self.Data[self.ind].L
        a = self.Data[self.ind].a
        M = self.Data[self.ind].M
        gl = self.Data[self.ind].gl
        G = self.Data[self.ind].g
        DIAG = self.Data[self.ind].diag
        self.ind += 1
        return (L, a, M, gl, G, DIAG)
