# -*- coding: utf-8 -*-
"""Test of the read_dgt_signal_ex_mat function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
from ltfatpy.tests.datasets.read_dgt_signal_ex_mat import DgtSignals
import numpy
import fractions
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestReadDgtSignalExt(unittest.TestCase):
    """ Test read_dgt_signal_ex.py """

    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('sepdgt_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        dgs = DgtSignals(self.filename)
        (TYPE, PHASETYPE, L, W, a, M, gl, SIGNAL, WINDOW, DGT, DUAL_WINDOW,
         IDGT) = dgs.read_next_signal()
        while TYPE != '':
            '''
            print ("\n\nTYPE = ", TYPE, "\nPHASETYPE = ", PHASETYPE, "\nL = ",
                   L, "\nW = ", W, "\na = ", a, "\nM = ", M, "\ngl = ",
                   gl, "\nSIGNAL =\n", SIGNAL, "\nWINDOW =\n", WINDOW,
                   "\nDGT\n", DGT, "\nDUAL_WINDOW\n", DUAL_WINDOW,
                   "\nIDGT\n", IDGT)
            '''

            assert (TYPE == "REAL" or TYPE == "CMPLX")
            assert (PHASETYPE == "freqinv" or PHASETYPE == "timeinv")
            assert isinstance(L, int)
            assert isinstance(W, int)
            assert isinstance(a, int)
            assert isinstance(M, int)
            assert isinstance(gl, int)
            assert type(SIGNAL).__module__ == numpy.__name__
            assert type(WINDOW).__module__ == numpy.__name__
            assert type(DGT).__module__ == numpy.__name__
            assert type(IDGT).__module__ == numpy.__name__
            assert WINDOW.size == gl
            if (gl == M):
                assert DUAL_WINDOW.size == gl
            elif (a != M):
                assert DUAL_WINDOW.size == a * M // fractions.gcd(a, M)
            else:
                assert DUAL_WINDOW.size == a * 2

            if W == 1:
                assert SIGNAL.size == L
                assert IDGT.size == L
            else:
                assert SIGNAL.shape == (L, W)
                assert IDGT.shape == (L, W)

            if TYPE == "REAL":
                if W == 1:
                    assert DGT.shape == ((M//2+1), L//a)
                else:
                    assert DGT.shape == ((M//2+1), L//a, W)
            else:
                if W == 1:
                    assert DGT.shape == (M, L//a)
                else:
                    assert DGT.shape == (M, L//a, W)
            (TYPE, PHASETYPE, L, W, a, M, gl, SIGNAL, WINDOW, DGT, DUAL_WINDOW,
             IDGT) = dgs.read_next_signal()

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestReadDgtSignalExt)
    unittest.TextTestRunner(verbosity=2).run(suite)
