# -*- coding: utf-8 -*-
"""Test of the dsti, dstii, dstiii, dstiv functions

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np


from ltfatpy.fourier.dsti import dsti
from ltfatpy.fourier.dstii import dstii
from ltfatpy.fourier.dstiii import dstiii
from ltfatpy.fourier.dstiv import dstiv
from ltfatpy.tests.datasets.read_comp_dst_signal_ex_mat import DstSignals
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestDST(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('comp_dst_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        dgs = DstSignals(self.filename)
        (TYPE, SIGNAL, L, W, DST, dst_type) = dgs.read_next_signal()
        while TYPE != '':
            mess = "\n\nTYPE = " + TYPE + "\nL = " + str(L)
            mess += "\nW = " + str(W) + "\ndst_type = " + str(dst_type)
            mess += "\nSIGNAL =\n" + str(SIGNAL)
            mess += "\nDST\n" + str(DST)
            if dst_type == 1:
                pydst = dsti(SIGNAL)
            elif dst_type == 2:
                pydst = dstii(SIGNAL)
            elif dst_type == 3:
                pydst = dstiii(SIGNAL)
            elif dst_type == 4:
                pydst = dstiv(SIGNAL)
            else:
                self.assertTrue(False, "Error in test datas")
            mess += "\npydst = \n" + str(pydst)
            self.assertTrue(np.linalg.norm(pydst-DST) <= 1e-10, mess)
            (TYPE, SIGNAL, L, W, DST, dst_type) = dgs.read_next_signal()

    def test_limit(self):
        """ Some limit tests
        """
        f = np.random.random_sample((128))
        pydst = dsti(f, 1)
        np.testing.assert_equal(f[0], pydst, "L = 1")
        pydst = dstii(f, 1)
        np.testing.assert_array_equal(f[0], pydst, "L = 1")
        pydst = dstiii(f, 1)
        np.testing.assert_array_equal(f[0], pydst, "L = 1")
        pydst = dstiv(f, 1)
        np.testing.assert_array_equal(f[0], pydst, "L = 1")


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestDST)
    unittest.TextTestRunner(verbosity=2).run(suite)
