# -*- coding: utf-8 -*-
"""Test of the fftreal function

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_allclose

from ltfatpy.fourier.fftreal import fftreal
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestFftreal(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestFftreal')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_shape(self):
        """Check that the output has the expected shape
        """
        shapes = ((4,), (4, 3), (4, 3, 2))
        N_val = (2, 3, 6, 7)
        inputs = {}
        for shape in shapes:
            inputs['f'] = np.random.random(shape)
            for dim in range(len(shape)):
                inputs['dim'] = dim
                for N in N_val:
                    inputs['N'] = N
                    c = fftreal(**inputs)
                    expected_shape = list(shape)
                    expected_shape[dim] = int(np.ceil((N+1.)/2.))
                    expected_shape = tuple(expected_shape)
                    msg = ('Wrong shape in the ouput of fftreal with inputs ' +
                           str(inputs))
                    self.assertEqual(c.shape, expected_shape, msg)

    def test_known(self):
        """Checking fftreal on some known results taken from Octave
        """
        filename = get_dataset_path('fftreal_ref.mat')
        data = read_ref_mat(filename)

        for inputs, outputs in data:
            h = fftreal(**inputs)
            msg = ('Wrong value in output of fftreal with inputs ' +
                   str(inputs))
            assert_allclose(h, outputs[0], rtol=5e-13, err_msg=msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestFftreal)
    unittest.TextTestRunner(verbosity=2).run(suite)
