# -*- coding: utf-8 -*-
"""Test of the isevenfunction function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
from ltfatpy.fourier import pgauss as pg
from ltfatpy.fourier import isevenfunction as ie


class TestIsEvenFunction(unittest.TestCase):
    """ Unittest class for Fourier isevenfunction"""
    def setUp(self):
        pass

    def tearDown(self):
        print('Test done')

    def test_default(self):
        self.assertRaises(ValueError, ie.isevenfunction, np.ones((2, 2)))

        g = pg.pgauss(20)[0]
        mess = "g = " + str(g) + ", L = 20, wp\n"
        self.assertTrue(ie.isevenfunction(g), mess)
        self.assertFalse(ie.isevenfunction(g, centering='hp'), mess)

        g = pg.pgauss(21, centering='hp')[0]
        mess = "g = " + str(g) + ", L = 21, hp\n"
        self.assertFalse(ie.isevenfunction(g), mess)
        self.assertTrue(ie.isevenfunction(g, centering='hp'), mess)

        self.assertRaises(ValueError, ie.isevenfunction, g, centering='foo')


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestIsEvenFunction)
    unittest.TextTestRunner(verbosity=2).run(suite)
