# -*- coding: utf-8 -*-
"""Test of the psech function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import random
import numpy as np
from numpy import linalg as LA
from math import sqrt
from ltfatpy.fourier.psech import psech


class TestPsech(unittest.TestCase):
    """ Unittest class for Fourier pgauss"""
    def setUp(self):
        self.L = random.randint(10, 100)

    def tearDown(self):
        print('Test done')

    def test_default(self):
        (g_r1, _) = psech(self.L)
        (g_r2, _) = psech(self.L, tfr=1, width=0.0, bw=0.0, c_f=0.0,
                          centering='wp', delay=0.0, norm='2')
        mess = "\nTest default values with L = " + str(self.L) + "\n"
        self.assertTrue(np.array_equal(g_r1, g_r2), mess)

    def test_exceptions(self):
        mess = "\nException TypeError should be raised with declaration "
        mess += "psech(10.2)\n"
        self.assertRaises(TypeError, psech, 10.2, mess)
        mess = "\nException TypeError should be raised with declaration "
        mess += "psech(10,(1,1))\n"
        self.assertRaises(TypeError, psech, 10, (1, 1))

    def test_invariance_property(self):
        g = psech(self.L)[0]
        gf = np.fft.fft(g)/sqrt(self.L)
        mess = "Test DFT invariance."
        self.assertAlmostEqual(LA.norm(g-gf), 0, 10, mess)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestPsech)
    unittest.TextTestRunner(verbosity=2).run(suite)
