# -*- coding: utf-8 -*-
"""Test of the gabdual function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
# from math import *
# import matplotlib.pyplot as plt
# from fractions import gcd

from ltfatpy.gabor.gabdual import gabdual
from ltfatpy.tests.datasets.read_dgt_signal_ex_mat import DgtSignals
from ltfatpy.fourier.pgauss import pgauss
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestGabDual(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('dgt_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        pass
        dgs = DgtSignals(self.filename)
        (TYPE, PHASETYPE, L, W, a, M, gl, SIGNAL, WINDOW, DGT, DUAL_WINDOW,
         IDGT) = dgs.read_next_signal()
        while TYPE != '':
            mess = "\n\nTYPE = " + TYPE + "\nPHASETYPE = " + PHASETYPE
            mess += "\nL = " + str(L) + "\nW = " + str(W) + "\na = " + str(a)
            mess += "\nM = " + str(M) + "\ngl = " + str(gl) + "\nSIGNAL =\n"
            mess += str(SIGNAL) + "\nWINDOW =\n" + str(WINDOW)
            mess += "\nDGT\n" + str(DGT) + "\nDUAL_WINDOW\n"
            mess += str(DUAL_WINDOW) + "\nIDGT\n" + str(IDGT)
            gd = gabdual(WINDOW, a, M)
            # mess += "\ng_dual = \n" + str(gd)
            self.assertTrue(np.linalg.norm(gd-DUAL_WINDOW) <= 1e-10, mess)
            (TYPE, PHASETYPE, L, W, a, M, gl, SIGNAL, WINDOW, DGT, DUAL_WINDOW,
             IDGT) = dgs.read_next_signal()

    def test_properties(self):
        self.assertRaises(ValueError, gabdual, "Gauss", 13, 89, 89)
        a = 20
        M = 49
        gd = gabdual("Gauss", a, M)
        L = gd.shape[0]
        g = pgauss(L)[0]
        gdd = gabdual(gd, a, M, L)
        mess = "a = {0:d}, M = {1:d}, L = {2:d}".format(a, M, L)
        np.testing.assert_array_almost_equal(g, gdd, 10, mess)
        gd = gabdual(g.reshape(L//2, 2), a, M)
        self.assertEqual(gd.shape, (2, L))
        M = 10
        gd = gabdual("Gauss", a, M)
        self.assertEqual(gd.shape, (a,))

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestGabDual)
    unittest.TextTestRunner(verbosity=2).run(suite)
