# -*- coding: utf-8 -*-
"""Test of the gabframediag function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
# from math import *
# import matplotlib.pyplot as plt
# from fractions import gcd

from ltfatpy.gabor.gabframediag import gabframediag
from ltfatpy.tests.datasets.read_gabframediag_signal_ex_mat import DiagExamples
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestGabFrameDiag(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('gabframediag_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        pass
        dgs = DiagExamples(self.filename)
        (L, a, M, gl, G, DIAG) = dgs.read_next_frame()
        while L != '':
            mess = "\nL = " + str(L) + "\na = " + str(a)
            mess += "\nM = " + str(M) + "\ngl = " + str(gl)
            mess += "\nG = " + str(G) + "\nDIAG = " + str(DIAG)
            d = gabframediag(G, a, M, L)
            self.assertTrue(np.linalg.norm(d-DIAG) <= 1e-10, mess)
            (L, a, M, gl, G, DIAG) = dgs.read_next_frame()

    def test_properties(self):
        self.assertRaises(ValueError, gabframediag, "Gauss", 6, 8, 16)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestGabFrameDiag)
    unittest.TextTestRunner(verbosity=2).run(suite)
