# -*- coding: utf-8 -*-
"""Test of the gabtight function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
# from math import *
# import matplotlib.pyplot as plt
# from fractions import gcd

from ltfatpy.gabor.gabtight import gabtight
from ltfatpy.tests.datasets.read_gabtight_signal_ex_mat import GabTightExamples
from ltfatpy.fourier.pgauss import pgauss
from ltfatpy.fourier.psech import psech
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestGabTight(unittest.TestCase):
    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('gabtight_signal_ex.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        pass
        dgs = GabTightExamples(self.filename)
        (L, a, M, rname, G, GT) = dgs.read_next_frame()
        while L != '':
            mess = "\nL = " + str(L) + "\na = " + str(a)
            mess += "\nM = " + str(M) + "\nrname = " + str(rname)
            mess += "\nG = " + str(G) + "\nGT = " + str(GT)
            t = gabtight(G, a, M, L)
            mess += "\ngt = " + str(t)
            self.assertTrue(np.linalg.norm(t-GT) <= 1e-10, mess)
            (L, a, M, rname, G, GT) = dgs.read_next_frame()

    def test_properties(self):
        self.assertRaises(ValueError, gabtight, "Gauss", 6, 8, 16)
        a = 10
        M = 40
        L = 160
        g = pgauss(L)[0]
        mess = "a = {0:d}, M = {1:d}, L = {2:d}".format(a, M, L)
        np.testing.assert_array_equal(gabtight(g, a, M), gabtight(g, a, M, L),
                                      mess)
        a = 20
        M = 49
        gt = gabtight("Gauss", a, M)
        L = gt.shape[0]
        mess = "a = {0:d}, M = {1:d}, L = {2:d}".format(a, M, L)
        np.testing.assert_array_almost_equal(gt, gabtight(None, a, M, L), 10,
                                             mess)
        g = pgauss(L)[0]
        gt = gabtight(g.reshape(L//2, 2), a, M)
        self.assertEqual(gt.shape, (L, 2))
        M = 10
        gt = gabtight("Gauss", a, M)
        self.assertEqual(gt.shape, (a,))
        gt1 = gabtight('sech', a, M)
        L = gt.shape[0]
        g = psech(L, a*M/L)[0]
        gt2 = gabtight(g, a, M)
        mess = "a = {0:d}, M = {1:d}".format(a, M)
        np.testing.assert_array_almost_equal(gt1, gt2, 10, mess)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestGabTight)
    unittest.TextTestRunner(verbosity=2).run(suite)
