# -*- coding: utf-8 -*-
"""Test of the instfreqplot function

NOTE: Only the non-graphical features of instfreqplot are tested here

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_allclose

from ltfatpy.gabor.instfreqplot import instfreqplot
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestInstfreqplot(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestInstfreqplot')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_exceptions(self):
        """Check that the right exceptions are raised when expected
        """
        # coef must be a 1D numpy.ndarray, check that we get the right
        # exceptions if not
        self.assertRaises(TypeError, instfreqplot, 'test')
        self.assertRaises(TypeError, instfreqplot, 1)
        self.assertRaises(TypeError, instfreqplot, 1.)
        self.assertRaises(TypeError, instfreqplot, [0, 2])
        self.assertRaises(ValueError, instfreqplot, np.ones((4, 2)))

        # wrong values of xres and yres should lead to exceptions
        self.assertRaises(ValueError, instfreqplot, np.random.random((20, )),
                          xres=3, yres=3)
        self.assertRaises(TypeError, instfreqplot, np.random.random((20, )),
                          xres='a', yres=3)

    def test_working(self):
        """Check that instfreqplot is working as expected
        """
        filename = get_dataset_path('instfreqplot_ref.mat')
        data = read_ref_mat(filename)

        for inputs, outputs in data:
            out = instfreqplot(**inputs)
            msg = ('Wrong value in output of instfreqplot with inputs ' +
                   str(inputs))
            assert_allclose(out, outputs[0], rtol=2e-15, err_msg=msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestInstfreqplot)
    unittest.TextTestRunner(verbosity=2).run(suite)
