# -*- coding: utf-8 -*-
"""Test of the phaseplot function

NOTE: Only the non-graphical features of phaseplot are tested here

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_allclose
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat

from ltfatpy.gabor.phaseplot import phaseplot
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestPhaseplot(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestPhaseplot')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_exceptions(self):
        """Check that the right exceptions are raised when expected
        """
        # coef must be a 1D numpy.ndarray, check that we get the right
        # exceptions if not
        self.assertRaises(TypeError, phaseplot, 'test')
        self.assertRaises(TypeError, phaseplot, 1)
        self.assertRaises(TypeError, phaseplot, 1.)
        self.assertRaises(TypeError, phaseplot, [0, 2])
        self.assertRaises(ValueError, phaseplot, np.ones((4, 2)))

    def test_working(self):
        """Check that phaseplot is working as expected
        """
        filename = get_dataset_path('phaseplot_ref.mat')
        data = read_ref_mat(filename)

        for inputs, outputs in data:
            out = phaseplot(**inputs)
            msg = ('Wrong value in output of phaseplot with inputs ' +
                   str(inputs))
            assert_allclose(out, outputs[0], rtol=2e-15, err_msg=msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestPhaseplot)
    unittest.TextTestRunner(verbosity=2).run(suite)
