# -*- coding: utf-8 -*-
"""Test of the phaseunlock function

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_array_equal

from ltfatpy.gabor.phaseunlock import phaseunlock
from ltfatpy.gabor.dgt import dgt
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestPhaseunlock(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestPhaseunlock')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_exceptions(self):
        """Check that the right exceptions are raised when expected
        """
        c = dgt(np.random.random((16,)), 'gauss', 2, 6)[0]
        # a is expected to be an integer, check that we get type error if not
        self.assertRaises(TypeError, phaseunlock, c, 'test')
        self.assertRaises(TypeError, phaseunlock, c, 1.0)
        self.assertRaises(TypeError, phaseunlock, c, (1, 2))
        # a should be the value used to generate c with dgt, check that we get
        # a value error if not
        self.assertRaises(ValueError, phaseunlock, c, 3)

    def test_known(self):
        """Check phaseunlock on some known results taken from Octave
        """
        filename = get_dataset_path('phaseunlock_ref.mat')
        data = read_ref_mat(filename)

        for inputs, outputs in data:
            out = phaseunlock(**inputs)
            msg = ('Wrong output in phaseunlock with inputs ' +
                   str(inputs))
            assert_array_equal(out, outputs[0], msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestPhaseunlock)
    unittest.TextTestRunner(verbosity=2).run(suite)
