# -*- coding: utf-8 -*-
"""Test of the plotdgt function

NOTE: Only the non-graphical features of plotdgt are tested here

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_array_equal

from ltfatpy.gabor.plotdgt import plotdgt

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestPlotdgt(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestPlotdgt')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_working(self):
        """Check that plotdgt is working as expected
        """
        coefs = (np.array([[1., 10.], [100., 1000.]]),
                 np.array([[1., 10.], [100., 1000.], [10000., 100000.]]),
                 np.array([[1., 10.], [100., 1000.], [10000., 100000.],
                           [1000000., 10000000.]]))
        outs = (np.array([[0., 20.], [40., 60.]]),
                np.array([[80., 100.], [0., 20.], [40., 60.]]),
                np.array([[120., 140.], [0., 20.], [40., 60.], [80., 100.]]))
        inputs = {}
        inputs['a'] = 1
        inputs['display'] = False

        for coef, out_ref in zip(coefs, outs):
            inputs['coef'] = coef
            out = plotdgt(**inputs)
            msg = ('wrong output in plotdgt with inputs ' + str(inputs))
            assert_array_equal(out_ref, out, msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestPlotdgt)
    unittest.TextTestRunner(verbosity=2).run(suite)
