# -*- coding: utf-8 -*-
"""Test of the plotdgtreal function

NOTE: Only the non-graphical features of plotdgtreal are tested here

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np
from numpy.testing import assert_array_equal

from ltfatpy.gabor.plotdgtreal import plotdgtreal

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestPlotdgtreal(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestPlotdgtreal')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_working(self):
        """Check that plotdgtreal is working as expected
        """
        out_ref = np.array([[0., 20.], [40., 60.], [80., 100.]])
        inputs = {}
        inputs['coef'] = np.array([[1., 10.], [100., 1000.],
                                  [10000., 100000.]])
        inputs['a'] = 1
        inputs['M'] = 1
        inputs['display'] = False
        out = plotdgtreal(**inputs)
        msg = ('wrong output in plotdgtreal with inputs ' + str(inputs))
        assert_array_equal(out_ref, out, msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestPlotdgtreal)
    unittest.TextTestRunner(verbosity=2).run(suite)
