# -*- coding: utf-8 -*-
"""Test of the s0norm function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np
# from math import *
# import matplotlib.pyplot as plt
# from fractions import gcd

from ltfatpy.gabor.s0norm import s0norm
from ltfatpy.tests.datasets.read_s0norm_ex_mat import S0Examples
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestS0Norm(unittest.TestCase):
    # Called before the tests.
    def setUp(self):
        self.filename = get_dataset_path('s0_norm_test.mat')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_default(self):
        """ Comparing results with Matlab generated ones
        """
        pass
        dgs = S0Examples(self.filename)
        (gl, R, dim, rel, G, S0, S0Shape) = dgs.read_next_frame()
        while gl != '':
            dim = dim - 1
            mess = "\ngl = " + str(gl) + "\nR = " + str(R)
            mess += "\ndim = " + str(dim) + "\nrel = " + str(rel)
            mess += "\nG = " + str(G) + "\nS0 = " + str(S0)
            mess += "\nS0Shape = " + str(S0Shape)
            if rel == 'rel':
                s0r = s0norm(G, True, dim)
            else:
                s0r = s0norm(G, False, dim)
            mess += "\ns0r = " + str(s0r)
            self.assertTrue(np.linalg.norm(np.squeeze(s0r)-S0) <= 1e-10, mess)
            if(len(s0r.shape) > 1):
                self.assertEqual(s0r.shape, tuple(S0Shape), mess)
            (gl, R, dim, rel, G, S0, S0Shape) = dgs.read_next_frame()

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestS0Norm)
    unittest.TextTestRunner(verbosity=2).run(suite)
