# -*- coding: utf-8 -*-
"""Test of the gspi function

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
from numpy.testing import assert_array_equal

from ltfatpy.signals.gspi import gspi
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path


class TestGspi(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestGspi')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_data(self):
        """ Checking that the read data match the expectations
        """
        filename = get_dataset_path('gspi_ref.mat')
        # Known values of samples as read by Octave with ltfat 2.1.0
        data = read_ref_mat(filename)
        inputs, outputs = data[0]
        (s, fs) = gspi()
        self.assertEqual(s.shape, outputs[0].shape,
                         'Wrong signal shape in gspi')
        assert_array_equal(s, outputs[0], 'Wrong sample values in gspi')
        self.assertEqual(fs, outputs[1], 'Wrong sampling frequency in gspi')


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestGspi)
    unittest.TextTestRunner(verbosity=2).run(suite)
