# -*- coding: utf-8 -*-
"""Test of the firkaiser function

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
from numpy.testing import assert_allclose

from ltfatpy.sigproc.firkaiser import firkaiser
from ltfatpy.tests.datasets.read_ref_mat import read_ref_mat
from ltfatpy.tests.datasets.get_dataset_path import get_dataset_path

# NOTE: The reference values used in the tests correspond to results
# obtained with Octave using ltfat 2.1.0


class TestFirkaiser(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestFirkaiser')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_exceptions(self):
        """Check that the right exceptions are raised when expected
        """
        L = 7
        # test with beta of wrong type (float is expected)
        self.assertRaises(TypeError, firkaiser, L, 'test')
        self.assertRaises(TypeError, firkaiser, L, [0.1, 0.2])
        self.assertRaises(TypeError, firkaiser, L, 7)

        """
        The following test is removed as long as the stype='derived'
        option is not implemented
        # L must be even when stype = 'derived'
        self.assertRaises(ValueError, firkaiser, L, 0.5, stype='derived')
        """

    def test_known(self):
        """Checking firkaiser on some known results taken from Octave
        """
        filename = get_dataset_path('firkaiser_ref.mat')
        data = read_ref_mat(filename)
        for inputs, outputs in data:
            """
            As long as the stype='derived' option is not implemented, we need
            to filter the tested values on the stype option
            """
            if inputs['stype'] == 'normal':
                inputs.pop('stype')
                out = firkaiser(**inputs)
                msg = ('Wrong value in output of firkaiser with inputs ' +
                       str(inputs))
                assert_allclose(out, outputs[0], rtol=1e-15, err_msg=msg)


if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestFirkaiser)
    unittest.TextTestRunner(verbosity=2).run(suite)
