# -*- coding: utf-8 -*-
"""Test of the long2fir function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np

from ltfatpy.sigproc.long2fir import long2fir


class TestSigprocLong2fir(unittest.TestCase):
    """ Unittest class for Sigproc long2fir"""
    digit = 9

    def setUp(self):
        pass

    def tearDown(self):
        print('Test done')

    def test_default(self):
        self.assertRaises(TypeError, long2fir, "foo", 10)
        self.assertRaises(ValueError, long2fir, np.ones(10), None)
        self.assertRaises(ValueError, long2fir, np.ones(10), 15)
        self.assertRaises(ValueError, long2fir, np.ones(10), 5,
                          centering='foo')

        gin = np.arange(20, dtype='f4')

        g = long2fir(gin, 10)
        np.testing.assert_array_equal(g, np.hstack((np.arange(5),
                                                    np.arange(15, 20))))
        g = long2fir(gin, 11)
        np.testing.assert_array_equal(g, np.hstack((np.arange(6),
                                                    np.arange(15, 20))))
        g = long2fir(gin, 10, centering='wp')
        np.testing.assert_array_equal(g, np.hstack((np.arange(5),
                                                    np.array([0]),
                                                    np.arange(16, 20))))
        g = long2fir(gin, 11, centering='hp')
        np.testing.assert_array_equal(g, np.hstack((np.arange(5),
                                                    np.array([0]),
                                                    np.arange(15, 20))))

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestSigprocLong2fir)
    unittest.TextTestRunner(verbosity=2).run(suite)
