# -*- coding: utf-8 -*-
"""Test of the normalize function

.. moduleauthor:: Denis Arrivault
"""

from __future__ import print_function, division

import unittest
import numpy as np

from ltfatpy.sigproc.normalize import normalize


class TestSigprocNormalize(unittest.TestCase):
    """ Unittest class for Sigproc normalize"""
    digit = 9

    def setUp(self):
        pass

    def tearDown(self):
        print('Test done')

    def test_default(self):
        self.assertRaises(TypeError, normalize, np.arange(10), 10)
        self.assertRaises(TypeError, normalize, np.arange(10, dtype='i8'),
                          'wav')
        norm_names = {'1', 'area', '2', 'energy', 'inf', 'peak', 'rms', 's0'}
        fin = np.arange(10, dtype=float)
        for n in norm_names:
            f, fnorm = normalize(fin, n)
            np.testing.assert_array_almost_equal(f*fnorm, fin, 6, "f = " +
                                                 str(f) + "\nfnorm = " +
                                                 str(fnorm) + '\n' + n
                                                 )
        f, fnorm = normalize(fin, 'wav')
        np.testing.assert_array_almost_equal(f*fnorm / 0.99, fin, 6, "f = " +
                                             str(f) + "\nfnorm = " +
                                             str(fnorm) + '\nwav')
        f1, fn1 = normalize(fin)
        f2, fn2 = normalize(fin, '2')
        np.testing.assert_array_equal(f1, f2)
        self.assertEqual(fn1, fn2)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestSigprocNormalize)
    unittest.TextTestRunner(verbosity=2).run(suite)
