# -*- coding: utf-8 -*-
"""Test of the lcm function

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

import unittest
import numpy as np

from ltfatpy.tools.lcm import lcm


class TestLcm(unittest.TestCase):

    # Called before the tests.
    def setUp(self):
        print('\nStart TestLcm')

    # Called after the tests.
    def tearDown(self):
        print('Test done')

    def test_types(self):
        """Checking input and output types
        """
        # test with str input, when int is expected
        self.assertRaises(TypeError, lcm, 2, '1')
        # test with float input, when int is expected
        self.assertRaises(TypeError, lcm, 2., 1)
        # check output type (int expected)
        self.assertEqual(type(lcm(3, 5)), int, '\nOutput type should be int')

    def test_known(self):
        """Checking lcm on some known results taken from Octave
        """
        ref = ((30, 12, 60), (-20, 15, -60), (6, -9, -18), (-12, -9, 36),
               (0, 3, 0), (-12, 0, -0), (0, 0, 0))
        inputs = {}
        for X, Y, res in ref:
            inputs['X'] = X
            inputs['Y'] = Y
            msg = 'Wrong output of lcm with inputs ' + str(inputs)
            self.assertEqual(lcm(**inputs), res, msg)

    def test_symmetry(self):
        """Checking that lcm is symmetric
        """
        values = np.random.randint(-1000, 1000, (5,))
        for X in values:
            for Y in values:
                X = int(X)
                Y = int(Y)
                msg = ('lcm is not symetric with X = {0:d} and '
                       'Y = {1:d}'.format(X, Y))
                self.assertEqual(lcm(X, Y), lcm(Y, X), msg)

    def test_primes(self):
        """Checking lcm with prime numbers
        """
        primes = (2, 3, 5, 7, 11, 13, 17)
        inputs = {}
        for X in primes:
            for Y in primes:
                inputs['X'] = X
                inputs['Y'] = Y
                msg = 'Wrong output of lcm with prime inputs ' + str(inputs)
                if inputs['X'] == inputs['Y']:
                    self.assertEqual(lcm(**inputs), inputs['X'], msg)
                else:
                    self.assertEqual(lcm(**inputs),
                                     inputs['X']*inputs['Y'], msg)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestLcm)
    unittest.TextTestRunner(verbosity=2).run(suite)
