# -*- coding: utf-8 -*-
"""This module computes the least common multiple

.. moduleauthor:: Florent Jaillet
"""

from __future__ import print_function, division

from fractions import gcd
from math import copysign


def lcm(X, Y):
    """Compute the least common multiple

    - Inputs:

    :param int X: The first of the two integers for which to compute the
                  least common multiple
    :param int Y: The second of the two integers for which to compute the
                  least common multiple

    - Outputs:

    :returns: Least common multiple of **X** and **Y**
    :rtype: int

    """

    if (not isinstance(X, int) or not isinstance(Y, int)):
        raise TypeError('X and Y must be int.')

    if Y == 0 or X == 0:
        return 0

    res = X * Y // gcd(X, Y)

    # Note: Some sign modification is needed to match the results in Octave
    # when we have negative values
    res = int(abs(res) * copysign(1, X) * copysign(1, Y))

    return res
